Welcome to DRF-Social-OAuth2
===================================

.. image:: https://badge.fury.io/py/drf-social-oauth2.svg
    :target: https://badge.fury.io/for/py/drf-social-oauth2

.. image:: https://www.codefactor.io/repository/github/wagnerdelima/drf-social-oauth2/badge
    :target: https://www.codefactor.io/repository/github/wagnerdelima/drf-social-oauth2/badge

Installation
------------

This framework is published at the PyPI, install it with pip::

    pip install drf_social_oauth2

Link to documentation
---------------------

You can read the whole drf-social-oauth2's documentation at: https://drf-social-oauth2.readthedocs.io/en/latest/.

Contributing
------------

Details `here <https://github.com/wagnerdelima/drf-social-oauth2/blob/master/CONTRIBUTING.md#:~:text=CODE_OF_CONDUCT.md-,CONTRIBUTING,-.md.>`_

What Am I Working Next?
^^^^^^^^^^^^^^^^^^^^^^^

I will be working on the issues below. Anyone is welcome to contribute.

    - Investigating Issues.

From Spain, with Love.
